# -*- coding: cp1252 -*-
# (C) by Fred Bayer <fred@bayerf.de>
#
# Display B 7971 tube 14 segment characters
# Also create retlw instructions for PIC assembler

from Tkinter import Tk, Canvas
from turtle import RawPen
from b7971font import segments, chars, printable

def line(x1,y1,x2,y2,x3=None,y3=None):
  global p
  p.up()
  p.goto(x1,y1)
  p.down()
  p.goto(x2,y2)
  if x3 and y3:
    p.goto(x3,y3)

def char(c):
  global p
  p.up()
  p.goto(-20,140)
  p.write("chr(%d) = %s" % (c, printable(chr(c))))
  for i,d in enumerate(chars[chr(c)][0:16]):
    if int(d):
      line(*segments[i])

curr = ord("A")
def refresh(event):
  global p, curr
  p.clear()
  try:
    #print event.__dict__
    if event.keysym == "Right":
      curr += 1
    elif event.keysym == "Left":
      curr -= 1
    elif event.keysym == "Up":
      curr -= 32
    elif event.keysym == "Down":
      curr += 32
    elif event.keysym == "Home":
      curr = 0
    elif event.keysym == "End":
      curr = 127
    elif event.keysym == "F1":
      export()
    else:
      curr = ord(event.char)
    curr &= 0x7f
    char(curr)
  except:
    pass

CODETEMPLATE = """\
    retlw   b'%s'         ; %s
"""    
def export():
  fn = "segments"
  if "UML" in chars:
    fn += "_uml"
  f = file(fn+"_lo.inc", "w")
  for i in range(0,128):
    c = chr(i)
    f.write(CODETEMPLATE % (chars[c][0:8], printable(c)))
  f.close()

  f = file(fn+"_hi.inc", "w")
  for i in range(0,128):
    c = chr(i)
    f.write(CODETEMPLATE % (chars[c][8:16], printable(c)))
  f.close()
  
def main():
  global p
  root = Tk()
  cv = Canvas(root, width=240, height=340, bg="black")
  cv.pack()
  p = RawPen(cv)
  p.tracer(False)
  p.width(5)
  p.up()
  p.goto(-80,-150)
  p.color("blue")
  p.write("Press F1 to export PIC include files")
  
  p.color("orange")
  char(curr)
  root.title("B7971 Font Viewer")
  root.bind("<KeyPress>", refresh)
  root.mainloop()

if __name__ == "__main__":
  main()
